//
//  CardDTO.h
//  LemonSDK
//
//  Created by Lemon on 1/21/13.
//  Copyright (c) 2013 Lemon. All rights reserved.
//

/*
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:
 
 1. Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
 
 2. Redistributions in binaryform must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided withthe distribution.
 
 THIS SOFTWARE IS PROVIDED BY THE LEMON INC``AS IS'' AND ANY EXPRESS OR
 IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 EVENT SHALL LEMON INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 

#import <Foundation/Foundation.h>

/**
 * Payment card brands Enum
 */
typedef enum{
    CardBrandAmex =        1,
    CardBrandDiners =      2,
    CardBrandDiscover =    3,
    CardBrandGE =          4,
    CardBrandJCB =         5,
    CardBrandMaestro =     6,
    CardBrandMaster =      7,
    CardBrandVisa =        8
}CardBrand;

/**
 * CardDTO is used to transfer the payment card information from the Lemon Network SDK to the application. 
 * The properties will be with data based on the SDK initialization and wich data is mandatory for the user to enter.
 */
@interface CardDTO : NSObject{
    // Payment card description.
    NSString *_description;
    
    // Payment card number with no format.
    NSString *_cardnumber;
    
    // Payment card name on card. Usually the cardholder full name.
    NSString *_cardholder;
    
    // Payment card expiry date in MM/YY format.
    NSString *_expiration;
    
    // Payment card verification value (CVV / CVV2 / CSC / CID). This information is not store in the Lemon Network.
    // This property is used to passthru the value entered by the user when it is required by the application.
    NSString *_CVV;
    
    // Payment card billing address.
    NSString *_address;
    
    // Payment card billing address city.
    NSString *_city;
    
    // Payment card billing address state.
    NSString *_state;
    
    // Payment card billing address zip code.
    NSString *_zip;
    
    // Payment card billing address countrycode ISO 3166-1 alfa-2.
    NSString *_countryCode;
    
    // Payment card access token. This is a UID used by the Lemon Network and the application to identify the card.
    NSString *_cardAccessToken;
    
    // Payment card brand ID based on the "Payment card brands Enum"
    NSNumber *_cardBrand;
    
    // Payment card brand name
    NSString *_cardBrandName;
    
    // Payment card brand logo image
    UIImage  *_cardBrandLogo;
}

@property(nonatomic, strong) NSString *description;
@property(nonatomic, strong) NSString *cardnumber;
@property(nonatomic, strong) NSString *cardholder;
@property(nonatomic, strong) NSString *expiration;
@property(nonatomic, strong) NSString *CVV;
@property(nonatomic, strong) NSString *address;
@property(nonatomic, strong) NSString *city;
@property(nonatomic, strong) NSString *state;
@property(nonatomic, strong) NSString *zip;
@property(nonatomic, strong) NSString *countryCode;
@property(nonatomic, strong) NSString *cardAccessToken;
@property(nonatomic, strong) NSNumber *cardBrand;
@property(nonatomic, strong) NSString *cardBrandName;
@property(nonatomic, strong) UIImage  *cardBrandLogo;

@end

