//
//  LemonSDK.h
//  LemonSDK
//
//  Created by Lemon on 11/29/12.
//  Copyright (c) 2012 Lemon. All rights reserved.
//

/*
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:
 
 1. Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
 
 2. Redistributions in binaryform must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided withthe distribution.
 
 THIS SOFTWARE IS PROVIDED BY THE LEMON INC``AS IS'' AND ANY EXPRESS OR
 IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 EVENT SHALL LEMON INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#import <Foundation/Foundation.h>
#import "LemonSDKDelegate.h"

/*
 * This are the two available Locale configurations for now. (USA & Brasil).
 * Default is USA.
 */
typedef NS_ENUM(NSInteger, LemonLocaleType) {
    LemonLocaleUS = 0,  // English - USA locale
    LemonLocaleBR,       // Portuguese - Brasil locale
    // Don't change!! Used as length
    LemonLocaleCount
};

/*
 * Interface to the Lemon Network SDK.
 *
 * With this class you can show the Lemon Network The SDK, it will either show (a) a list of payment cards 
 * the user already has used with the option to add a new card, or (b) a prompt to add a first card.
 *
 * Sample integration code:
 * In your .m:
 *
 *     #import "LemonSDK.h"
 *
 *      - (void) showLemonSDK{
 *              LemonSDK *lsdk = [[LemonSDK alloc]initWithDelegate:self
 *                          accessToken:<ACCESS_TOKEN>
 *                          email:<USER_EMAIL>
 *              [lsdk showLemonWallet];
 *      }
 *
 *      Make sure that your AccessToken and SDK configuration options are correct, 
 *      and specify a delegate object that implements the LemonSDKDelegate protocol.
 */

@interface LemonSDK : NSObject

//  Delegate that implements the LemonSDKDelegate userDidProvideCard method
@property (nonatomic, weak) id<LemonSDKDelegate>    delegate;

//  Enumeration to configure Locale
@property (nonatomic, assign) LemonLocaleType       locale;

//  <Developer secret key>
@property (nonatomic, copy) NSString                *UUID;

//  <ACCESS_TOKEN>
@property (nonatomic, copy) NSString                *accessToken;

//  <USER_EMAIL> is the application user's personal email
@property (nonatomic, copy) NSString                *email;

//  <TRANSACTION_CURRENCY> currency value to process payment with developer's configured processor
@property (nonatomic, copy) NSString                *currency;

//  <TRANSACTION_DESCRIPTION> description value to process payment with developer's configured processor
@property (nonatomic, copy) NSString                *description;

//  <TRANSACTION_TOTAL_AMOUNT> total amount value to process payment with developer's configured processor
@property (nonatomic, copy) NSNumber                *totalAmount;

// Init the Lemon Network SDK based on the information that is required to ask to the application user in the checkout process
- (id)initWithDelegate:(id)delegate accessToken:(NSString *)accessToken email:(NSString *)email locale:(LemonLocaleType)locale;

// Init the Lemon Network SDK based on the information that is required to ask to the application user in the checkout executing payment transaction using the processor configured in lemon's developer site
- (id)initWithDelegate:(id)delegate accessToken:(NSString *)accessToken email:(NSString *)email locale:(LemonLocaleType)locale currency:(NSString *)currency description:(NSString *)description totalAmount:(NSNumber *)totalAmount;

// Show the Lemon Network SDK view controller
- (void)showLemonWallet;

@end
