//
//  LemonSDKDelegate.h
//  LemonSDK
//
//  Created by Lemon on 12/17/12.
//  Copyright (c) 2012 Lemon. All rights reserved.
//

/*
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:
 
 1. Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
 
 2. Redistributions in binaryform must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided withthe distribution.
 
 THIS SOFTWARE IS PROVIDED BY THE LEMON INC``AS IS'' AND ANY EXPRESS OR
 IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 EVENT SHALL LEMON INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#import <Foundation/Foundation.h>
#import "CardDTO.h"
#import "TransactionDTO.h"

/*
 * Interface to the Lemon Network SDK.
 *
 * This class follows the Delegate pattern, so your application should implement the userDidProvideCard method
 * to get the payment card information in the CardDTO class
 *
 * Sample integration code:
 * In your .h:
 *
 *     #import "LemonSDKDelegate.h"
 *
 *     @interface ViewController : UIViewController <LemonSDKDelegate>
 *
 * In your .m:
 *      - (void) userDidProvideCard:(CardDTO *)info{
 *          NSString *response = @"SDK CLOSED - LEMON CARD NIL";
 *          if(info){
 *              // ie PROCESS PAYMENT WITH CARD DATA IN info
 *          }
 *      }
 *      - (void)transactionDidSuccess:(TransactionDTO *)info {
 *          NSString *response = @"SDK CLOSED - LEMON CARD NIL";
 *          if(info){
 *              // ie PROCESS PAYMENT WITH CARD DATA IN info
 *          }
 *      }
 */

@protocol LemonSDKDelegate <NSObject>

- (void) userDidProvideCard:(CardDTO *)info;
- (void) transactionDidComplete:(TransactionDTO *)info;

@end
