//
//  ViewController.m
//  LemonSDKTest
//
//  Created by Fabian on 12/5/12.
//  Copyright (c) 2012 Lemon. All rights reserved.
//

#import "ViewController.h"
#import "LandingPageViewController.h"
#import "StoreFileManager.h"


@interface ViewController ()

@property (nonatomic, strong) LandingPageViewController *landingController;
@property (nonatomic, assign) LemonLocaleType locale;
@property (nonatomic, strong) StoreFileManager *fm;
@property (nonatomic, weak) IBOutlet UIView *maskView;
@property (nonatomic, weak) IBOutlet UIView *settingsMaskView;

@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    [self setLandingController:nil];
    _fm = [[StoreFileManager alloc] init];
    if([self.fm doesFileExists:@"email"]) {
        [self.email setText:[[NSString alloc] initWithData:[self.fm getDataWithName:@"email"] encoding:NSUTF8StringEncoding]];
    } else {
        [self.fm writeData:[@"test1000@lemonstore.com" dataUsingEncoding:NSUTF8StringEncoding] withName:@"email"];
        [self.email setText:@"test1000@lemonstore.com"];
    }
    [self.pickLanguage setHidden:YES];
    [self.maskView setHidden:YES];
    [self.settingsMaskView setHidden:YES];
    [self setLocale:LemonLocaleUS];
    [self.currency setEnabled:NO];
    [self.currency setText:@"USD"];
    [self.amount setEnabled:NO];
    [self.amount setText:@"2550"];
    [self.description setEnabled:NO];
    [self.description setText:@"Trip"];
    [self.processPayment setOn:NO];
}

- (void)viewDidAppear:(BOOL)animated {
    [super viewDidAppear:animated];
    if ([self landingController]) {
        [self presentViewController:[self landingController] animated:YES completion:nil];
        [self setLandingController:nil];
    }
}

- (void) userDidProvideCard:(CardDTO *)info {
    // This is the come-back point to your app from Lemon's workflow. You can use the info object to access the payment data.
    [self setLandingController:[[LandingPageViewController alloc] initWithNibName:@"LandingPageViewController" bundle:nil]];
    [self.landingController setLocale:self.locale];
}

- (void)transactionDidComplete:(TransactionDTO *)info {
    // This is the come-back point to your app from Lemon's payment transaction workflow. You can use the info object to access the payment successfull execution data.
    [self setLandingController:[[LandingPageViewController alloc] initWithNibName:@"LandingPageViewController" bundle:nil]];
    [self.landingController setLocale:self.locale];
}

- (IBAction)gotoSDK:(id)sender {
    [self.fm writeData:[self.email.text dataUsingEncoding:NSUTF8StringEncoding] withName:@"email"];
    LemonSDK *lsdk = nil;
    if ([self.processPayment isOn]) {
        lsdk = [[LemonSDK alloc] initWithDelegate:self accessToken:@"1e422bafac8521e422bafb40" email:self.email.text locale:self.locale currency:self.currency.text description:self.description.text totalAmount:@([self.amount.text integerValue])];
    } else {
        lsdk = [[LemonSDK alloc] initWithDelegate:self accessToken:@"1e422bafac8521e422bafb40" email:self.email.text locale:self.locale];
    }
    [lsdk showLemonWallet];
}

- (IBAction)gotoSettings:(id)sender {
    if(self.settingsView.alpha == 0) {
        [UIView beginAnimations:nil context:NULL];
        [UIView setAnimationDuration:0.5];
        [UIView setAnimationCurve:UIViewAnimationCurveEaseInOut];
        [UIView setAnimationDelegate:self];
        self.settingsView.alpha = 1;
        [UIView commitAnimations];
        [self.settingsMaskView setHidden:NO];
    } else {
        [UIView beginAnimations:nil context:NULL];
        [UIView setAnimationDuration:0.5];
        [UIView setAnimationCurve:UIViewAnimationCurveEaseInOut];
        [UIView setAnimationDelegate:self];
        self.settingsView.alpha = 0;
        [UIView commitAnimations];
        [self.email resignFirstResponder];
        [self.settingsMaskView setHidden:YES];
    }
}

- (IBAction)settingsMaskViewTapped:(id)sender {
    [UIView beginAnimations:nil context:NULL];
    [UIView setAnimationDuration:0.5];
    [UIView setAnimationCurve:UIViewAnimationCurveEaseInOut];
    [UIView setAnimationDelegate:self];
    self.settingsView.alpha = 0;
    [UIView commitAnimations];
    [self.email resignFirstResponder];
    [self.settingsMaskView setHidden:YES];
}

- (IBAction)togglePayment:(id)sender {
    if ([self.processPayment isOn]) {
        [self.currency setEnabled:YES];
        [self.amount setEnabled:YES];
        [self.description setEnabled:YES];
    } else {
        [self.currency setEnabled:NO];
        [self.amount setEnabled:NO];
        [self.description setEnabled:NO];
    }
}

- (IBAction)selectLanguage:(id)sender {
    if ([self.pickLanguage isHidden]) {
        [self.pickLanguage setHidden:NO];
        [self.maskView setHidden:NO];
        [self.settingsMaskView setHidden:YES];
    }
}

- (IBAction)maskViewTapped:(id)sender {
    [self.pickLanguage setHidden:YES];
    [self.maskView setHidden:YES];
    [self.settingsMaskView setHidden:NO];
}

- (NSInteger)numberOfComponentsInPickerView:(UIPickerView *)pickerView {
    return 1;
}

- (NSInteger)pickerView:(UIPickerView *)pickerView numberOfRowsInComponent:(NSInteger)component {
    return LemonLocaleCount;
}

- (NSString *)pickerView:(UIPickerView *)pickerView titleForRow:(NSInteger)row forComponent:(NSInteger)component {
    switch (row) {
        case LemonLocaleBR:
            return @"Portuguese (Brasil)";
            break;
        default:
            return @"English (US)";
            break;
    }
}

- (void)pickerView:(UIPickerView *)pickerView didSelectRow:(NSInteger)row inComponent:(NSInteger)component {
    [self setLocale:row];
    [self.pickLanguage setHidden:YES];
    [self.maskView setHidden:YES];
    [self.settingsMaskView setHidden:NO];
    switch (self.locale) {
        case LemonLocaleBR:
            [self.labelProcessPayment setText:@"Processo de pagamento"];
            [self.labelAmount setText:@"Quantidade"];
            [self.labelCurrency setText:@"Moeda"];
            [self.labelDescription setText:@"Descrição"];
            [self.buttonProcessLanguage setTitle:@"Sem Idioma" forState:UIControlStateNormal];
            [self.background setImage:[UIImage imageNamed:@"lemonstore_br.png"]];
            break;
        case LemonLocaleUS:
        default:
            [self.labelProcessPayment setText:@"Process Payment"];
            [self.labelAmount setText:@"Amount"];
            [self.labelCurrency setText:@"Currency"];
            [self.labelDescription setText:@"Description"];
            [self.buttonProcessLanguage setTitle:@"Select Language" forState:UIControlStateNormal];
            [self.background setImage:[UIImage imageNamed:@"lemonstore.png"]];
            break;
    }
}

- (BOOL)textFieldShouldReturn:(UITextField *)textField {
    switch (textField.tag) {
        case 0:
            if ([self.processPayment isOn]) {
                [self.amount becomeFirstResponder];
            } else {
                [self.email resignFirstResponder];
            }
            return YES;
            break;
        case 1:
            [self.currency becomeFirstResponder];
            return YES;
            break;
        case 2:
            [self.description becomeFirstResponder];
            return YES;
            break;
        case 3:
            [self.description resignFirstResponder];
            return YES;
            break;
        default:
            break;
    }
    return NO;
}


@end
